smartcard.Exceptions

# ``smartcard`.`Exceptions``

module documentation

Smartcard module exceptions.

This module defines the exceptions raised by the smartcard module.

__author__ = "http://www.gemalto.com"

Copyright 2001-2012 gemalto Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com

This file is part of pyscard.

pyscard is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

pyscard is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with pyscard; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Exception | `CardConnectionException` | Raised when a CardConnection class method fails.
Exception | `CardRequestException` | Raised when a CardRequest wait fails.
Exception | `CardRequestTimeoutException` | Raised when a CardRequest times out.
Exception | `CardServiceException` | Raised when a CardService class method fails.
Exception | `CardServiceStoppedException` | Raised when the CardService was stopped
Exception | `InvalidATRMaskLengthException` | Raised when an ATR mask does not match an ATR length.
Exception | `InvalidReaderException` | Raised when trying to acces an invalid smartcard reader.
Exception | `ListReadersException` | Raised when smartcard readers cannot be listed.
Exception | `NoCardException` | Raised when no card in is present in reader.
Exception | `NoReadersException` | Raised when the system has no smartcard reader.
Exception | `SmartcardException` | Base class for smartcard exceptions.